import axios from "axios";
import i18next from "i18next";
import { localStorage } from "@flare/js-utils";
import { storageKeys } from "./identity";

const { getItem } = localStorage;

function getHeaders() {
  const token = getItem(storageKeys.TOKEN);
  const language = i18next.language;

  return {
    "Content-Type": "application/json",
    Authorization: `Basic ${token.raw}`,
    "Accept-Language": `${language}`
  };
}

async function internalRequest(url, options) {
  try {
    const res = await axios.request(url, options);
    return res.data;
  } catch (error) {
    if (error.response && error.response.data) {
      throw (
        {
          ...error.response.data,
          message: error.response.data.detail || error.response.data.title
        } || error
      );
    }
    // The request was made but no response was received
    // `error.request` is an instance of XMLHttpRequest in the browser and an instance of
    // http.ClientRequest in node.js
    throw error;
  }
}

export const request = (url, options) => internalRequest(url, options);

export function post(url, data) {
  const options = {
    method: "post",
    data: JSON.stringify(data),
    headers: getHeaders()
  };

  return internalRequest(url, options);
}

export function put(url, data) {
  const options = {
    method: "put",
    data: JSON.stringify(data),
    headers: getHeaders()
  };

  return internalRequest(url, options);
}

export function del(url, data) {
  const options = {
    method: "delete",
    data: JSON.stringify(data),
    headers: getHeaders()
  };

  return internalRequest(url, options);
}

export function get(url) {
  const options = {
    method: "GET",
    headers: getHeaders()
  };
  return internalRequest(url, options);
}
